@@ -78,6 +78,7 @@ class DjangoPushDataHandler(object):
         return True
 
     def _insert0(self, database, table, data, action):
+        data2 = None
         try:
             model_item = self._get_model(database, table)
             if not model_item:
@@ -101,7 +102,7 @@ class DjangoPushDataHandler(object):
             sd.log_warn("IntegrityError for table={0} data={1}".format(table, data))
         except Exception as ex:
             sd.log_exception(ex)
-            sd.log_error("execption for table={0} data={1}".format(table, data))
+            sd.log_error("execption for table={0} data={1} data2={2} action={3}".format(table, data,data2,action))
             raise ex
 
     def update(self, database, table, data):
